#
# spec file for package proton-vpn
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?suse_version} >= 1600
%global pythons python3
%else
%global pythons python311
%endif
Name:           proton-vpn
Version:        4.7.4
Release:        1.3
Summary:        Official Proton VPN client
License:        GPL-3.0-or-later
Group:          Productivity/Networking/Security
URL:            https://github.com/ProtonVPN/proton-vpn-gtk-app
Source:         https://github.com/ProtonVPN/proton-vpn-gtk-app/archive/refs/tags/v%{version}.tar.gz
BuildRequires:  %{python_module dbus-python}
BuildRequires:  %{python_module distro}
BuildRequires:  %{python_module gobject}
BuildRequires:  %{python_module packaging}
BuildRequires:  %{python_module proton-core}
BuildRequires:  %{python_module proton-vpn-api-core >= 0.25.0}
BuildRequires:  %{python_module proton-vpn-network-manager}
BuildRequires:  %{python_module pycairo}
BuildRequires:  %{python_module pytest-cov}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module requests}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  gobject-introspection
BuildRequires:  gtk3-devel
BuildRequires:  python-rpm-macros
BuildRequires:  update-desktop-files
Requires:       %{pythons}-dbus-python
Requires:       %{pythons}-distro
Requires:       %{pythons}-gobject
Requires:       %{pythons}-packaging
Requires:       %{pythons}-proton-core
Requires:       %{pythons}-proton-vpn-api-core >= 0.35.2
Requires:       %{pythons}-proton-vpn-network-manager >= 0.9.1
Requires:       %{pythons}-pycairo
Requires:       %{pythons}-requests
Requires:       gtk3
Conflicts:      protonvpn-gui
Provides:       protonvpn-app = %{version}
BuildArch:      noarch

%description
The Proton VPN client is easy to use and packed with advanced features
carefully designed to improve your online security.

%prep
%setup -q -n proton-vpn-gtk-app-%{version}
%autopatch -p1

%build
%python_build

%install
%python_install
%fdupes %{buildroot}%{python_sitelib}/

mkdir -p %{buildroot}/%{_datadir}/icons/hicolor/scalable/apps/
mkdir -p %{buildroot}/%{_datadir}/applications
cp rpmbuild/SOURCES/proton-vpn-logo.svg %{buildroot}/%{_datadir}/icons/hicolor/scalable/apps/proton-vpn.svg

%suse_update_desktop_file -c proton-vpn "Proton VPN" "Proton VPN Client" protonvpn-app proton-vpn "GTK;Network;Utility"

%check
# ignore UI tests as they segfault with no desktop env
%pytest tests/unit --ignore=tests/unit/widgets/

%files
%doc README.md
%license LICENSE COPYING.md
%{_datadir}/applications/proton-vpn.desktop
%{_datadir}/icons/hicolor/*/apps/proton-vpn.*
%{python_sitelib}/proton/
%{python_sitelib}/proton_vpn_gtk_app-%{version}*.egg-info
%{_bindir}/protonvpn-app

%changelog
* Tue Nov 12 2024 Alexandre Vicenzi <alexandre.vicenzi@suse.com>
- Update package to 4.7.4:
  * Fix bug when opening settings window, if installed via unsupported methods the early access toggle would crash.
  * Fix bug when opening the settings window and advanced kill switch is enabled the settings would crash.
  * Update kill switch and protocol label, clarifying that they can be switched only when disconnected from vpn
  * Fix introduced regression as it was no longer deactivating the selection of protocol and kill switch while being connected to VPN
  * Add start-app-minimized to settings window
  * Remove killswitch dependencies in setup.py as packages have been deprecated
  * Merge community MR to allow the app to start minimized based on CLI arguments
  * Drop secret service package
  * Drop logger package
  * Fix regression when moving refreshers
  * Move refreshers to core API
  * Add back scheduler after memory leak fix
  * When toggling IPv6 ensure that user is notified that a reconnection is necessary and prevent certificate refresh
  * Add IPv6 toggle to settings window
  * Switch back to old scheduler due to memory leak in new one
  * Show VPN accelerator setting disabled to free users
  * Don't display reconnect message when connected via WireGuard protocol and settings are switched
  * Changes due to api-core refactor
  * Request connection features via local agent if available.
  * Added a MaximumSessionsReached event to the list of events that can be emitted.
  * Update package URL used by early release settings toggle.
  * Refresh certificate whenever the app receives an expired certificate event.
  * Only display WireGuard protocol if already selected or if feature flag is enabled, otherwise hide it.
  * Fix wrong imports after core api refactor.
  * Implement and refresh feature flags.
  * When early access is toggled, ensure that repo package can be downloaded, otherwise display error message.
  * Add early access toggle to settings window.
  * Move the scripts for generating the changelogs into a separate repo.
  * Only allow kill switch settings modifications when disconnected from the VPN.
  * Log the user out on session expired error while updating certificate.
  * Implement exponential backoff when retrying to refresh certificate.
  * Fix task scheduler after suspending/resuming the computer.
  * Refactor settings to ensure the settings file isn't created when we retrieve it.
  * Disable protocol selection if user is connected to vpn.
- Remove setup-data-files.patch
* Wed May 22 2024 Alexandre Vicenzi <alexandre.vicenzi@suse.com>
- Add setup-data-files.patch to fix erroneous files being installed
- Update package
  * 4.3.2
  - We no longer call UsageReporting.init to initialize UsageReporting.
  - Only initialize sentry on first enable.
  - Forward SSL_CERT_FILE environment variable to sentry.
  * 4.3.1
  - Ensure behavioral consistency when opening settings window across different distributions
  - Update label alignment on disable kill switch widget at login
  - Missed the minimum python3-proton-vpn-api-core version in build_packages.py
  - Switch to using sessions module that is now bundled with vpn-api-core
  - Update wireguard certificate request when settings are changed
  - Add connection features to the wireguard certificate request
  - Periodically refresh certificate
  * 4.3.0
  - Provide the possibility to disable Kill Switch if user is logged out and Kill Switch is set to permanent
  - Ensure that protocol list in settings UI is properly capitalized and alphabetically ordered
  - Anonymous crash reports are now sent by default, this can be disabled in the settings
  - Change how we build debian and rpm packages. We now depend on a single versions.yml file to build everything
  - Increase minimum number of characters required for bug report description
* Thu Mar 21 2024 Alexandre Vicenzi <alexandre.vicenzi@suse.com>
- Update to 4.2.0
  * Add overlay when connecting to server
  * Upon logging out or quitting, inform the user about the kill switch status
  * Apply kill switch settings immediately
  * Add permanent option to kill switch setting
  * Fix minor bug in country row initialization
* Fri Feb  9 2024 Alexandre Vicenzi <alexandre.vicenzi@suse.com>
- Initial revision
